import Store from "@packages/store";
/**
 * 将对象转成 a=1&b=2的形式
 * @param obj 对象
 */
function obj2String(obj) {
  let idx = 0,
    arr = [];
  for (let item in obj) {
    arr[idx++] = [item, obj[item]];
  }
  return new URLSearchParams(arr).toString();
}

/**
 * 添加默认请求的参数
 * @param {*} options
 */
function getOptions(options) {
  const { sid, corp_id, node_env } = Store;
  const params = {
    sid: node_env === "uat" ? null : sid,
    corp_id,
    ...options
  };
  return obj2String(params);
}

/**
 * 真正的请求
 * @param url 请求地址
 * @param options 请求参数
 * @param method 请求方式
 */
function request(url, options, method = "GET") {
  const staticOption = {
    sid: Store.sid,
    corp_id: Store.corp_id
  };
  options = {
    ...staticOption,
    ...options
  };
  const searchStr = getOptions(options);
  const staticSearchStr = getOptions(staticOption);
  let initObj = {};
  if (method === "GET") {
    // 如果是GET请求，拼接url
    url += "?" + searchStr;
    initObj = {
      method: method,
      credentials: "include"
    };
  } else {
    initObj = {
      method: method,
      credentials: "include",
      headers: new Headers({
        Accept: "application/json, text/plain, */*",
        "Content-Type": "application/json"
      }),
      body: JSON.stringify(options)
    };
    url += "?" + staticSearchStr;
  }
  return fetch(url, initObj)
    .then(res => {
      return res.json();
    })
    .then(res => {
      return res;
    });
}

/**
 * GET请求
 * @param url 请求地址
 * @param options 请求参数
 */
export const GET = (url, options) => {
  return request(url, options, "GET");
};

/**
 * POST请求
 * @param url 请求地址
 * @param options 请求参数
 */
export const POST = (url, options) => {
  return request(url, options, "POST");
};
